require "james_bond/core/mission"
require "james_bond/mission_kubernetes/config"
require "james_bond/mission_kubernetes/patch_deploy_handler"

module JamesBond
  class KubernetesDeployMission
    include JamesBond::Core::Mission

    MISSION_NAME            = "kubernetes_deploy"
    MISSION_MAIN_COMMANDS   = ["deploy"]
    CONFIGURATION_FILE_PATH = File.join(
      Dir.pwd, "config", "james_bond", "kubernetes.yml"
    )

    def build(config, params)
      config.name          = MISSION_NAME
      config.main_commands = MISSION_MAIN_COMMANDS

      arguments_parser do |parser|
        parser.banner =  "bond #{MISSION_MAIN_COMMANDS[0]} [options]"
        parser.string  "-t", "--tag", "The image tag to deploy."
        parser.string "-e", "--environment",
          "Environment to deploy to. Default: dev.",
          default: "dev"
      end
    end

    def run_deploy_command(command:, mission_pool:)
      tag = command.options[:tag]
      tag ||= invoke_build(mission_pool)[:tag]

      command.options[:tag] = tag
      MissionKubernetes::PatchDeployHandler.new(command, config_file).run
    end

    private

    def invoke_build(mission_pool)
      build = JamesBond::Core::Command.new( argv: ["build"], env: "dev")
      build_mission = mission_pool.decide_mission(build)
      build_mission.run_command(command: build, mission_pool: mission_pool)
    end

    def config_file
      @config_file ||= JamesBond::MissionKubernetes::Config.new(yaml_path: CONFIGURATION_FILE_PATH)
    end
  end
end
