require "james_bond/core/mission"
require "james_bond/mission_kubernetes/server_handler"
require "james_bond/mission_kubernetes/config"

module JamesBond
  class KubernetesServerMission
    include JamesBond::Core::Mission

    MISSION_NAME            = "kubernetes_server"
    MISSION_MAIN_COMMANDS   = ["server"]
    CONFIGURATION_FILE_PATH = File.join(
      Dir.pwd, "config", "james_bond", "kubernetes.yml"
    )

    def build(config, params)
      config.name          = MISSION_NAME
      config.main_commands = MISSION_MAIN_COMMANDS

      arguments_parser do |parser|
        parser.banner =  "bond #{MISSION_MAIN_COMMANDS[0]} [options]"
        parser.string "-t", "--tag",
          "Use this option to specify what image tag to use. " + \
          "Remember the image should be accessible to the docker deamon used "+ \
          "by Kubernetes. If you are using Minikube run " + \
          "`eval $(minikube docker-env)` to share de deamon."
        parser.separator "  "
      end
    end

    def run_server_command(command:)
      MissionKubernetes::ServerHandler.new(command, config_file).run
    end

    def config_file
      @config_file ||= JamesBond::MissionKubernetes::Config.new(yaml_path: CONFIGURATION_FILE_PATH)
    end
  end
end
