require "james_bond/core/mission"
require "james_bond/mission_kubernetes/config"
require "james_bond/mission_kubernetes/test_handler"

module JamesBond
  class KubernetesTestMission
    include JamesBond::Core::Mission

    MISSION_NAME            = "kubernetes"
    MISSION_MAIN_COMMANDS   = ["test"]
    CONFIGURATION_FILE_PATH = File.join(Dir.pwd, "config", "james_bond", "kubernetes.yml")

    def build(config, params)
      config.name          = MISSION_NAME
      config.main_commands = MISSION_MAIN_COMMANDS
    end

    def run_test_command(command:, mission_pool: )
      build_output = invoke_build(mission_pool)

      command.env = "test" #FIXME
      command.options = (command.options || {}).merge("tag" => build_output[:tag])
      JamesBond::MissionKubernetes::TestHandler.new(command, config_file).run
    end

    private

    def invoke_build(mission_pool)
      build = JamesBond::Core::Command.new( argv: ["build"], env: "dev")
      build_mission = mission_pool.decide_mission(build)
      build_mission.run_command(command: build, mission_pool: mission_pool)
    end

    def config_file
      @config_file ||= JamesBond::MissionKubernetes::Config.new(yaml_path: CONFIGURATION_FILE_PATH)
    end
  end
end
