require "open3"
require "json"

module JamesBond
  class MissionKubernetes
    class PatchDeployHandler
      attr_accessor :config

      def initialize(command, config)
        @command = command
        @config  = config.for(
          env: command.options[:environment],
          command: command.main_command
        )
      end

      def run
        command = [
          "kubectl",
          "patch",
          "deployment #{app_name}",
          "-p '#{JSON.dump(spec)}'",
        ]

        command = switch_environment(command).join(' ')
        puts command

        Open3.popen3(command) do |stdin, stdout, stderr, thread|
          Thread.new do
            until (line = stdout.gets).nil? do
              puts line
            end
          end

          Thread.new do
            until (line = stderr.gets).nil? do
              puts line
            end
          end

          thread.join
        end
      end

      private

      def switch_environment(patch_command)
        if @command.options[:environment] == 'production'
          patch_command << ["--kubeconfig=#{kubeconfig}"]
        else
          patch_command
        end
      end

      def kubeconfig
        File.join(Dir.pwd, @config["kubeconfig_path"])
      end

      def app_name
        @config["app_name"]
      end

      def image_name
        @config["image_name"]
      end

      def target
        "#{image_name}:#{@command.options[:tag]}"
      end

      def spec
        {
          spec: {
            template: {
              spec: {
                containers: [ { name: app_name, image: target } ]
              }
            }
          }
        }
      end
    end
  end
end
